@@ -3,8 +3,10 @@ import os
 from logging import *
 import logging.config
 
-from .filter import HostAddressFilter, RequestAddressFilter, ConcurrentIdFilter
+from .ding_alarm import ding_alarm
+from .filter import HostAddressFilter, RequestAddressFilter, ConcurrentIdFilter, NameFilter
 from .weather import weather_report
+from ..config.config_base import config
 
 __all__ = ["logging"]
 
@@ -27,7 +29,28 @@ def logger_report(self, msg: str, weather: bool = False, *args, **kwargs):
         weather_report()
 
 
+def error(self, msg: str, is_alarm: bool = True, *args, **kwargs):
+    """
+    Report error for logger, support report alarm
+
+    :param msg: dict, error content
+    :param is_alarm: bool, report to alarm, default is True
+    """
+    if is_alarm:
+        ding_alarm.send_alarm_message(msg)
+    if self.isEnabledFor(ERROR):
+        self._log(ERROR, msg, args, **kwargs)
+
+
 logging.Logger.report = logger_report
+logging.Logger.error = error
+log_level = config.get_log_level_config()
+
+# 是否禁用第三方日志(用户名不为当前用户名)
+filter_list = ["hostname", "source_ip", "concurrent_id"]
+if log_level["third_log"]:
+    filter_list.append("name")
+
 
 logging_config = {
     "version": 1,
@@ -46,21 +69,24 @@ logging_config = {
         },
         "concurrent_id": {
             "()": ConcurrentIdFilter
+        },
+        "name": {
+            "()": NameFilter
         }
     },
     "handlers": {
         "console": {
             "class": "logging.StreamHandler",
-            "level": "DEBUG",
+            "level": log_level["console"],
             "formatter": "winhye",
-            "filters": ["hostname", "source_ip", "concurrent_id"]
+            "filters": filter_list
         },
         "file": {
-            'level': "DEBUG",
+            'level': log_level["file"],
             "class": "winhye_common.winhye_handlers.time_handler.CommonTimedRotatingFileHandler",
             "filename": os.path.join(log_dir, "log.log"),
             "formatter": "winhye",
-            "filters": ["hostname", "source_ip", "concurrent_id"],
+            "filters": filter_list,
             "when": "H",
             "interval": 1,
             "backupCount": 168
